==> qtjambi-webenginecore-5.15.14-sources.jar: io/qt/webengine/core/QWebEngineUrlRequestInterceptor.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Abstract base class for URL interception</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html">QWebEngineUrlRequestInterceptor</a></p>
 */
public abstract class QWebEngineUrlRequestInterceptor extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineUrlRequestInterceptor.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QWebEngineUrlRequestInterceptor {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void interceptRequest(io.qt.webengine.core.@StrictNonNull QWebEngineUrlRequestInfo info){
            java.util.Objects.requireNonNull(info, "Argument 'info': null not expected.");
            interceptRequest_native_ref_QWebEngineUrlRequestInfo(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(info));
        }
        @QtUninvokable
        private native void interceptRequest_native_ref_QWebEngineUrlRequestInfo(long __this__nativeId, long info);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>p = null</code>.</p>
     */
    public QWebEngineUrlRequestInterceptor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html#QWebEngineUrlRequestInterceptor-1">QWebEngineUrlRequestInterceptor::QWebEngineUrlRequestInterceptor(QObject*)</a></p>
     */
    public QWebEngineUrlRequestInterceptor(io.qt.core.@Nullable QObject p){
        super((QPrivateConstructor)null);
        initialize_native(this, p);
    }
    
    private native static void initialize_native(QWebEngineUrlRequestInterceptor instance, io.qt.core.QObject p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html#interceptRequest">QWebEngineUrlRequestInterceptor::interceptRequest(QWebEngineUrlRequestInfo&amp;)</a></p>
     */
    @QtUninvokable
    public abstract void interceptRequest(io.qt.webengine.core.@StrictNonNull QWebEngineUrlRequestInfo info);
    
    @QtUninvokable
    private native void interceptRequest_native_ref_QWebEngineUrlRequestInfo(long __this__nativeId, long info);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineUrlRequestInterceptor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QWebEngineUrlRequestInterceptor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QWebEngineUrlRequestInterceptor instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-webenginecore-5.15.15-sources.jar: io/qt/webengine/core/QWebEngineUrlRequestInterceptor.java <==
package io.qt.webengine.core;

import io.qt.*;


/**
 * <p>Abstract base class for URL interception</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html">QWebEngineUrlRequestInterceptor</a></p>
 */
public abstract class QWebEngineUrlRequestInterceptor extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineUrlRequestInterceptor.class);
    
    @NativeAccess
    private static final class ConcreteWrapper extends QWebEngineUrlRequestInterceptor {
        
        @NativeAccess
        private ConcreteWrapper(QPrivateConstructor p) { super(p); }
        
        @Override
        @QtUninvokable
        public void interceptRequest(io.qt.webengine.core.@StrictNonNull QWebEngineUrlRequestInfo info){
            java.util.Objects.requireNonNull(info, "Argument 'info': null not expected.");
            interceptRequest_native_ref_QWebEngineUrlRequestInfo(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(info));
        }
        @QtUninvokable
        private native void interceptRequest_native_ref_QWebEngineUrlRequestInfo(long __this__nativeId, long info);
        
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QWebEngineUrlRequestInterceptor(io.qt.core.QObject)}
     *  with <code>p = null</code>.</p>
     */
    public QWebEngineUrlRequestInterceptor() {
        this((io.qt.core.QObject)null);
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html#QWebEngineUrlRequestInterceptor-1">QWebEngineUrlRequestInterceptor::QWebEngineUrlRequestInterceptor(QObject*)</a></p>
     */
    public QWebEngineUrlRequestInterceptor(io.qt.core.@Nullable QObject p){
        super((QPrivateConstructor)null);
        initialize_native(this, p);
    }
    
    private native static void initialize_native(QWebEngineUrlRequestInterceptor instance, io.qt.core.QObject p);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebengineurlrequestinterceptor.html#interceptRequest">QWebEngineUrlRequestInterceptor::interceptRequest(QWebEngineUrlRequestInfo&amp;)</a></p>
     */
    @QtUninvokable
    public abstract void interceptRequest(io.qt.webengine.core.@StrictNonNull QWebEngineUrlRequestInfo info);
    
    @QtUninvokable
    private native void interceptRequest_native_ref_QWebEngineUrlRequestInfo(long __this__nativeId, long info);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineUrlRequestInterceptor(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QWebEngineUrlRequestInterceptor(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QWebEngineUrlRequestInterceptor instance, QDeclarativeConstructor constructor);
    
}
